@@ -1,21 +1,17 @@
-# encoding: utf-8
-
-"""
-Test data builders for numbering part XML elements
-"""
+"""Test data builders for numbering part XML elements."""
 
 from ...unitdata import BaseBuilder
 
 
 class CT_NumBuilder(BaseBuilder):
-    __tag__ = 'w:num'
-    __nspfxs__ = ('w',)
-    __attrs__ = ('w:numId')
+    __tag__ = "w:num"
+    __nspfxs__ = ("w",)
+    __attrs__ = "w:numId"
 
 
 class CT_NumberingBuilder(BaseBuilder):
-    __tag__ = 'w:numbering'
-    __nspfxs__ = ('w',)
+    __tag__ = "w:numbering"
+    __nspfxs__ = ("w",)
     __attrs__ = ()
 
 
